<?php
/**
 * Utilisations de pipelines par Menu Boutique
 *
 * @plugin     Menu Boutique
 * @copyright  2022
 * @author     Anne-lise Martenot
 * @licence    GNU/GPL
 * @package    SPIP\Menu_boutique\Pipelines
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/*
 * Pipeline du menu de navigation SPIP privé
 * Déplacer les boutons de certains plugins vers le menu boutique
 */
function menu_boutique_ajouter_menus($flux){
	
	$flux['menu_boutique'] = 
	new Bouton(
		find_in_theme("images/boutique.svg"), 
		'Boutique', 
		generer_url_ecrire("navigation","menu=menu_boutique")
	);
	
	$flux['menu_boutique']->sousmenu['mots'] = 
	new Bouton(
		find_in_theme("images/mots.png"), 
		'Etiquettes', 
		generer_url_ecrire("mots")
		);
	
	// Commandes
	if(test_plugin_actif('commandes')){
		$flux['menu_boutique']->sousmenu['commandes'] = 
		new Bouton(
			find_in_theme("images/commande-xx.svg"), 
			'Commandes', 
			generer_url_ecrire("commandes")
			);
	}

	// Transactions / Bank
	if(test_plugin_actif('bank')){
		$flux['menu_boutique']->sousmenu['transactions'] = 
		new Bouton(
			find_in_theme("images/transaction-xx.svg"), 
			'Transactions', 
			generer_url_ecrire("transactions")
			);
	}
	
	// Factures
	if(test_plugin_actif('factures')){
		$flux['menu_boutique']->sousmenu['factures'] = 
		new Bouton(
			find_in_theme("images/facture-xx.svg"), 
			'Factures', 
			generer_url_ecrire("factures")
			);
	}
	
	// Stocks
	if(test_plugin_actif('stocks')){
		$flux['menu_boutique']->sousmenu['stocks'] = 
		new Bouton(
			find_in_theme("images/stocks.png"), 
			'Stocks', 
			generer_url_ecrire("gerer_stocks")
		);
	}

	// Coordonnees
	if(test_plugin_actif('coordonnees')){
		$flux['menu_boutique']->sousmenu['coordonnees'] = 
		new Bouton(
			find_in_theme("images/coordonnees-xx.svg"), 
			'Coordonnees', 
			generer_url_ecrire("coordonnees")
			);
	}
	
	// Produits
	if(test_plugin_actif('produits')){
		$config_produits = lire_config('produits');
		$id_rubrique_boutique = $config_produits['limiter_ident_secteur'][0];
		$url_rubrique_boutique = generer_url_ecrire("rubrique&id_rubrique=$id_rubrique_boutique");
		$url_rubriques = generer_url_ecrire("rubriques");
		$url = (intval($id_rubrique_boutique) > 0) ? $url_rubrique_boutique : $url_rubriques;
		$titre_rubrique_boutique = sql_getfetsel('titre','spip_rubriques','id_rubrique ='.intval($id_rubrique_boutique));
		
		$flux['menu_boutique']->sousmenu['categories'] = 
		new Bouton(
			find_in_theme("images/rubrique.svg"), 
			$titre_rubrique_boutique ? $titre_rubrique_boutique : 'Catégories', 
			$url
			);
	
		$flux['menu_boutique']->sousmenu['produits'] = 
		new Bouton(
			find_in_theme("images/produits-xx.svg"), 
			'Produits', 
			generer_url_ecrire("produits")
			);
	}

	// Livraison
	if(test_plugin_actif('livraison')){
		$flux['menu_boutique']->sousmenu['livraisonmodes'] = 
		new Bouton(
			find_in_theme("images/livraison-xx.svg"), 
			'Modes de livraison', 
			generer_url_ecrire("livraisonmodes")
			);
	}

	// Réordonner la liste
	$flux['menu_boutique']->sousmenu['reordonner'] = 
		new Bouton(
			find_in_theme("images/reordonner-xx.svg"), 
			'x Réordonner la liste x', 
			ancre_url(generer_url_ecrire("configurer_preferences"),'menu_fav_categories')
		);
	
	//favoris cf function inc_definir_menus_favoris_dist
	/*
	$liste = [
		// Menu Boutique
		'auteurs' => 1,
		'rubriques' => 2,
		'articles' => 3,
	];*/

	// retirer les menus que l'on a mis dans celui de boutique
	unset($flux['menu_activite']->sousmenu['commandes']);
	unset($flux['menu_activite']->sousmenu['transactions']);
	unset($flux['menu_activite']->sousmenu['factures']);
	unset($flux['menu_edition']->sousmenu['coordonnees']);
	unset($flux['menu_edition']->sousmenu['produits']);
	unset($flux['menu_edition']->sousmenu['livraisonmodes']);
	unset($flux['menu_edition']->sousmenu['gerer_stocks']);
	
	return $flux;
	
}